* doc/tutorial/examples/examples.mk
* doc/tutorial/figures/figures.mk
* doc/tutorial/outputs/outputs.mk
* doc/tutorial/samples/samples.mk: Update generated files.
* headers.mk: add new header to distribution.
* mln/core/alias/all.hh: new header.
* mln/core/alias/vec3d.hh: new aliases for 3d algebra::vec.
* mln/core/alias/box2d.hh,
* mln/core/alias/box3d.hh: update comments.
* mln/core/all.hh: include alias/all.hh.
* mln/essential/3d.hh: add image3d.hh and vec3d.hh.
* tests/unit_test/Makefile.am,
* tests/unit_test/mln_core_alias_all.cc,
* tests/unit_test/mln_core_alias_vec3d.cc,
* tests/unit_test/mln_make_image3d.cc: add new unit test files.
---
milena/doc/tutorial/examples/examples.mk | 1 -
milena/doc/tutorial/figures/figures.mk | 1 -
milena/doc/tutorial/outputs/outputs.mk | 1 -
milena/doc/tutorial/samples/samples.mk | 1 -
milena/headers.mk | 3 +
milena/mln/core/alias/{box2d.hh => all.hh} | 66 +++++++++++++----------
milena/mln/core/alias/box2d.hh | 27 +++++-----
milena/mln/core/alias/box3d.hh | 27 +++++-----
milena/mln/core/alias/{box3d.hh => vec3d.hh} | 30 +++++------
milena/mln/core/all.hh | 1 +
milena/mln/essential/3d.hh | 2 +
milena/tests/unit_test/Makefile.am | 3 +
milena/tests/unit_test/mln_core_alias_all.cc | 11 ++++
milena/tests/unit_test/mln_core_alias_vec3d.cc | 11 ++++
milena/tests/unit_test/mln_make_image3d.cc | 11 ++++
15 files changed, 118 insertions(+), 78 deletions(-)
copy milena/mln/core/alias/{box2d.hh => all.hh} (56%)
copy milena/mln/core/alias/{box3d.hh => vec3d.hh} (71%)
create mode 100644 milena/tests/unit_test/mln_core_alias_all.cc
create mode 100644 milena/tests/unit_test/mln_core_alias_vec3d.cc
create mode 100644 milena/tests/unit_test/mln_make_image3d.cc
diff --git a/milena/doc/tutorial/examples/examples.mk b/milena/doc/tutorial/examples/examples.mk
index 146f068..7458ead 100644
--- a/milena/doc/tutorial/examples/examples.mk
+++ b/milena/doc/tutorial/examples/examples.mk
@@ -1,6 +1,5 @@
## Generated by ../generate_dist_files, do not modify ##
EXTRA_DIST += \
-examples \
examples/cpp_issue.cc \
examples/sub_image.cc \
examples/sub_image_if.cc \
diff --git a/milena/doc/tutorial/figures/figures.mk b/milena/doc/tutorial/figures/figures.mk
index 3d11a2b..aba2682 100644
--- a/milena/doc/tutorial/figures/figures.mk
+++ b/milena/doc/tutorial/figures/figures.mk
@@ -1,6 +1,5 @@
## Generated by ../generate_dist_files, do not modify ##
EXTRA_DIST += \
-figures \
figures/ima2d-rot-2.ppm \
figures/tuto3_rw_image-1.ppm \
figures/logical-not-2.pbm \
diff --git a/milena/doc/tutorial/outputs/outputs.mk b/milena/doc/tutorial/outputs/outputs.mk
index 7d7596d..c6d318a 100644
--- a/milena/doc/tutorial/outputs/outputs.mk
+++ b/milena/doc/tutorial/outputs/outputs.mk
@@ -1,6 +1,5 @@
## Generated by ../generate_dist_files, do not modify ##
EXTRA_DIST += \
-outputs \
outputs/win-create-1-display.txt \
outputs/win-create-2.txt \
outputs/accu-right-instanciation.txt \
diff --git a/milena/doc/tutorial/samples/samples.mk b/milena/doc/tutorial/samples/samples.mk
index 7213ed1..40b410d 100644
--- a/milena/doc/tutorial/samples/samples.mk
+++ b/milena/doc/tutorial/samples/samples.mk
@@ -1,6 +1,5 @@
## Generated by ../generate_dist_files, do not modify ##
EXTRA_DIST += \
-samples \
samples/paste-call-1.cc \
samples/dpoint-1.cc \
samples/parray-append.cc \
diff --git a/milena/headers.mk b/milena/headers.mk
index 74a3002..037b5cc 100644
--- a/milena/headers.mk
+++ b/milena/headers.mk
@@ -134,6 +134,7 @@ mln/trace/stop.hh \
mln/trace/essential.hh \
mln/make/graph.hh \
mln/make/double_neighb2d.hh \
+mln/make/image3d.hh \
mln/make/dpoint2d_h.hh \
mln/make/w_window.hh \
mln/make/image.hh \
@@ -800,11 +801,13 @@ mln/core/alias/p_run2d.hh \
mln/core/alias/point3d.hh \
mln/core/alias/neighb3d.hh \
mln/core/alias/window3d.hh \
+mln/core/alias/all.hh \
mln/core/alias/neighb2d.hh \
mln/core/alias/complex_image.hh \
mln/core/alias/w_window1d_float.hh \
mln/core/alias/neighb1d.hh \
mln/core/alias/w_window2d_float.hh \
+mln/core/alias/vec3d.hh \
mln/core/alias/w_window2d_int.hh \
mln/core/alias/box1d.hh \
mln/core/alias/box2d.hh \
diff --git a/milena/mln/core/alias/box2d.hh b/milena/mln/core/alias/all.hh
similarity index 56%
copy from milena/mln/core/alias/box2d.hh
copy to milena/mln/core/alias/all.hh
index fb51e5d..ce509a6 100644
--- a/milena/mln/core/alias/box2d.hh
+++ b/milena/mln/core/alias/all.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007, 2008 EPITA Research and Development Laboratory
+// Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -25,34 +25,42 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_BOX2D_HH
-# define MLN_CORE_SITE_SET_BOX2D_HH
+#ifndef MLN_CORE_ALIAS_ALL_HH
+# define MLN_CORE_ALIAS_ALL_HH
-/*! \file mln/core/alias/box2d.hh
- *
- * \brief Definition of the mln::box2d alias and of construction
- * routines.
- */
+/// \file mln/core/alias/all.hh
+///
+/// File that includes all the aliases.
-# include <mln/core/site_set/box.hh>
-# include <mln/core/alias/point2d.hh>
+#include <box1d.hh>
+#include <box2d.hh>
+#include <box2d_h.hh>
+#include <box3d.hh>
+#include <complex_geometry.hh>
+#include <complex_image.hh>
+#include <dpoint1d.hh>
+#include <dpoint2d.hh>
+#include <dpoint2d_h.hh>
+#include <dpoint3d.hh>
+#include <neighb1d.hh>
+#include <neighb2d.hh>
+#include <neighb3d.hh>
+#include <p_run2d.hh>
+#include <p_runs2d.hh>
+#include <point1d.hh>
+#include <point2d.hh>
+#include <point2d_h.hh>
+#include <point3d.hh>
+#include <point3df.hh>
+#include <vec3d.hh>
+#include <w_window1d_float.hh>
+#include <w_window1d_int.hh>
+#include <w_window2d_float.hh>
+#include <w_window2d_int.hh>
+#include <w_window3d_float.hh>
+#include <w_window3d_int.hh>
+#include <window1d.hh>
+#include <window2d.hh>
+#include <window3d.hh>
-
-namespace mln
-{
-
- /*! \brief Type alias for a box defined on the 2D square grid with
- * integer coordinates.
- *
- * \see mln::win::rectangle2d.
- */
- typedef box<mln::point2d> box2d;
-
-
-} // end of namespace mln
-
-
-# include <mln/make/box2d.hh>
-
-
-#endif // ! MLN_CORE_SITE_SET_BOX2D_HH
+#endif // ! MLN_CORE_ALIAS_ALL_HH
diff --git a/milena/mln/core/alias/box2d.hh b/milena/mln/core/alias/box2d.hh
index fb51e5d..20cae3b 100644
--- a/milena/mln/core/alias/box2d.hh
+++ b/milena/mln/core/alias/box2d.hh
@@ -1,4 +1,5 @@
-// Copyright (C) 2007, 2008 EPITA Research and Development Laboratory
+// Copyright (C) 2007, 2008, 2009 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -25,14 +26,13 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_BOX2D_HH
-# define MLN_CORE_SITE_SET_BOX2D_HH
+#ifndef MLN_CORE_ALIAS_BOX2D_HH
+# define MLN_CORE_ALIAS_BOX2D_HH
-/*! \file mln/core/alias/box2d.hh
- *
- * \brief Definition of the mln::box2d alias and of construction
- * routines.
- */
+/// \file mln/core/alias/box2d.hh
+///
+/// Definition of the mln::box2d alias and of construction
+/// routines.
# include <mln/core/site_set/box.hh>
# include <mln/core/alias/point2d.hh>
@@ -41,11 +41,10 @@
namespace mln
{
- /*! \brief Type alias for a box defined on the 2D square grid with
- * integer coordinates.
- *
- * \see mln::win::rectangle2d.
- */
+ /// Type alias for a box defined on the 2D square grid with
+ /// integer coordinates.
+ ///
+ /// \see mln::win::rectangle2d.
typedef box<mln::point2d> box2d;
@@ -55,4 +54,4 @@ namespace mln
# include <mln/make/box2d.hh>
-#endif // ! MLN_CORE_SITE_SET_BOX2D_HH
+#endif // ! MLN_CORE_ALIAS_BOX2D_HH
diff --git a/milena/mln/core/alias/box3d.hh b/milena/mln/core/alias/box3d.hh
index 54beaf6..4deafb7 100644
--- a/milena/mln/core/alias/box3d.hh
+++ b/milena/mln/core/alias/box3d.hh
@@ -1,4 +1,5 @@
-// Copyright (C) 2007 EPITA Research and Development Laboratory
+// Copyright (C) 2007, 2009 EPITA Research and Development Laboratory
+// (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -25,14 +26,13 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_BOX3D_HH
-# define MLN_CORE_SITE_SET_BOX3D_HH
+#ifndef MLN_CORE_ALIAS_BOX3D_HH
+# define MLN_CORE_ALIAS_BOX3D_HH
-/*! \file mln/core/alias/box3d.hh
- *
- * \brief Definition of the mln::box3d alias and of construction
- * routines.
- */
+/// \file mln/core/alias/box3d.hh
+///
+/// Definition of the mln::box3d alias and of construction
+/// routines.
# include <mln/core/site_set/box.hh>
# include <mln/core/alias/point3d.hh>
@@ -41,11 +41,10 @@
namespace mln
{
- /*! \brief Type alias for a box defined on the 3D square grid with
- * integer coordinates.
- *
- * \see mln::win::rectangle3d.
- */
+ /// Type alias for a box defined on the 3D square grid with
+ /// integer coordinates.
+ ///
+ /// \see mln::win::rectangle3d.
typedef box<point3d> box3d;
@@ -55,4 +54,4 @@ namespace mln
# include <mln/make/box3d.hh>
-#endif // ! MLN_CORE_SITE_SET_BOX3D_HH
+#endif // ! MLN_CORE_ALIAS_BOX3D_HH
diff --git a/milena/mln/core/all.hh b/milena/mln/core/all.hh
index f92dbd8..d0ab2c3 100644
--- a/milena/mln/core/all.hh
+++ b/milena/mln/core/all.hh
@@ -34,6 +34,7 @@
// Sub-directories.
+# include <mln/core/alias/all.hh>
# include <mln/core/concept/all.hh>
# include <mln/core/def/all.hh>
# include <mln/core/image/all.hh>
diff --git a/milena/mln/essential/3d.hh b/milena/mln/essential/3d.hh
index 8d782c6..ec1a602 100644
--- a/milena/mln/essential/3d.hh
+++ b/milena/mln/essential/3d.hh
@@ -34,11 +34,13 @@
# include <mln/core/alias/dpoint3d.hh>
# include <mln/core/alias/neighb3d.hh>
# include <mln/core/alias/point3d.hh>
+# include <mln/core/alias/vec3d.hh>
# include <mln/core/alias/w_window3d_float.hh>
# include <mln/core/alias/w_window3d_int.hh>
# include <mln/core/alias/window3d.hh>
# include <mln/geom/size3d.hh>
# include <mln/make/box3d.hh>
+# include <mln/make/image3d.hh>
# include <mln/make/w_window3d.hh>
# include <mln/make/w_window3d_int.hh>
# include <mln/metal/array3d.hh>
diff --git a/milena/tests/unit_test/Makefile.am b/milena/tests/unit_test/Makefile.am
index 0475cc4..2653f23 100644
--- a/milena/tests/unit_test/Makefile.am
+++ b/milena/tests/unit_test/Makefile.am
@@ -131,6 +131,7 @@ mln_trace_stop \
mln_trace_essential \
mln_make_graph \
mln_make_double_neighb2d \
+mln_make_image3d \
mln_make_dpoint2d_h \
mln_make_w_window \
mln_make_image \
@@ -791,11 +792,13 @@ mln_core_alias_p_run2d \
mln_core_alias_point3d \
mln_core_alias_neighb3d \
mln_core_alias_window3d \
+mln_core_alias_all \
mln_core_alias_neighb2d \
mln_core_alias_complex_image \
mln_core_alias_w_window1d_float \
mln_core_alias_neighb1d \
mln_core_alias_w_window2d_float \
+mln_core_alias_vec3d \
mln_core_alias_w_window2d_int \
mln_core_alias_box1d \
mln_core_alias_box2d \
diff --git a/milena/tests/unit_test/mln_core_alias_all.cc b/milena/tests/unit_test/mln_core_alias_all.cc
new file mode 100644
index 0000000..97f068e
--- /dev/null
+++ b/milena/tests/unit_test/mln_core_alias_all.cc
@@ -0,0 +1,11 @@
+// Unit test for mln/core/alias/all.hh.
+// Generated by ./build_unit_test.sh, do not modify.
+
+// Include the file twice, so we detect missing inclusion guards.
+#include <mln/core/alias/all.hh>
+#include <mln/core/alias/all.hh>
+
+int main()
+{
+ // Nothing.
+}
diff --git a/milena/tests/unit_test/mln_core_alias_vec3d.cc b/milena/tests/unit_test/mln_core_alias_vec3d.cc
new file mode 100644
index 0000000..476c522
--- /dev/null
+++ b/milena/tests/unit_test/mln_core_alias_vec3d.cc
@@ -0,0 +1,11 @@
+// Unit test for mln/core/alias/vec3d.hh.
+// Generated by ./build_unit_test.sh, do not modify.
+
+// Include the file twice, so we detect missing inclusion guards.
+#include <mln/core/alias/vec3d.hh>
+#include <mln/core/alias/vec3d.hh>
+
+int main()
+{
+ // Nothing.
+}
diff --git a/milena/tests/unit_test/mln_make_image3d.cc b/milena/tests/unit_test/mln_make_image3d.cc
new file mode 100644
index 0000000..85fbb01
--- /dev/null
+++ b/milena/tests/unit_test/mln_make_image3d.cc
@@ -0,0 +1,11 @@
+// Unit test for mln/make/image3d.hh.
+// Generated by ./build_unit_test.sh, do not modify.
+
+// Include the file twice, so we detect missing inclusion guards.
+#include <mln/make/image3d.hh>
+#include <mln/make/image3d.hh>
+
+int main()
+{
+ // Nothing.
+}
diff --git a/milena/mln/core/alias/box3d.hh b/milena/mln/core/alias/vec3d.hh
similarity index 71%
copy from milena/mln/core/alias/box3d.hh
copy to milena/mln/core/alias/vec3d.hh
index 54beaf6..621b505 100644
--- a/milena/mln/core/alias/box3d.hh
+++ b/milena/mln/core/alias/vec3d.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007 EPITA Research and Development Laboratory
+// Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -25,28 +25,24 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
#ifndef MLN_CORE_SITE_SET_BOX3D_HH
# define MLN_CORE_SITE_SET_BOX3D_HH
/*! \file mln/core/alias/box3d.hh
*
* \brief Definition of the mln::box3d alias and of construction
* routines.
*/
# include <mln/core/site_set/box.hh>
# include <mln/core/alias/point3d.hh>
namespace mln
{
- /*! \brief Type alias for a box defined on the 3D square grid with
- * integer coordinates.
- *
- * \see mln::win::rectangle3d.
- */
- typedef box<point3d> box3d;
+ /// 3D vector with float coordinates.
+ typedef algebra::vec<3u,float> vec3d_f;
+
+ /// 3D vector with double coordinates.
+ typedef algebra::vec<3u,double> vec3d_d;
} // end of namespace mln
@@ -55,4 +51,4 @@ namespace mln
# include <mln/make/box3d.hh>
-#endif // ! MLN_CORE_SITE_SET_BOX3D_HH
+#endif // ! MLN_CORE_ALIAS_VEC3D_HH
@@ -25,28 +25,24 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_CORE_SITE_SET_BOX3D_HH
-# define MLN_CORE_SITE_SET_BOX3D_HH
+#ifndef MLN_CORE_ALIAS_VEC3D_HH
+# define MLN_CORE_ALIAS_VEC3D_HH
-/*! \file mln/core/alias/box3d.hh
- *
- * \brief Definition of the mln::box3d alias and of construction
- * routines.
- */
+/// \file mln/core/alias/vec3d.hh
+///
+/// Definition of the mln::vec3d* alias
-# include <mln/core/site_set/box.hh>
-# include <mln/core/alias/point3d.hh>
+# include <mln/algebra/vec.hh>
namespace mln
{
--
1.5.6.5